#===========================================================
# Jetty Startup 
#
# Starting Jetty from this {jetty.home} is not recommended.
#
# A proper {jetty.base} directory should be configured, instead
# of making changes to this {jetty.home} directory.
#
# See documentation about {jetty.base} at
# http://www.eclipse.org/jetty/documentation/current/startup.html
#
# A demo-base directory has been provided as an example of
# this sort of setup.
#
# $ cd demo-base
# $ java -jar ../start.jar
#
#===========================================================

# To disable the warning message, comment the following line
--module=home-base-warning


# --------------------------------------- 
# Module: server
--module=server
##
## Server Threading Configuration
##
# minimum number of threads
threads.min=10
# maximum number of threads
threads.max=200
# thread idle timeout in milliseconds
threads.timeout=60000
# buffer size for output
jetty.output.buffer.size=32768
# request header buffer size
jetty.request.header.size=8192
# response header buffer size
jetty.response.header.size=8192
# should jetty send the server version header?
jetty.send.server.version=true
# should jetty send the date header?
jetty.send.date.header=false
# What host to listen on (leave commented to listen on all interfaces)
#jetty.host=myhost.com
# Dump the state of the Jetty server, components, and webapps after startup
jetty.dump.start=false
# Dump the state of the Jetty server, before stop
jetty.dump.stop=false
# Enable delayed dispatch optimisation
jetty.delayDispatchUntilContent=false

# --------------------------------------- 
# Module: deploy
--module=deploy
## DeployManager configuration
# Monitored Directory name (relative to jetty.base)
# jetty.deploy.monitoredDirName=webapps


# --------------------------------------- 
# Module: websocket
--module=websocket

# --------------------------------------- 
# Module: ext
--module=ext

# --------------------------------------- 
# Module: resources
--module=resources

# --------------------------------------- 
# Module: jsp
--module=jsp
# JSP Configuration

# Select JSP implementation, choices are
#   glassfish : The reference implementation
#               default in jetty <= 9.1
#   apache    : The apache version
#               default jetty >= 9.2
jsp-impl=apache

# To use a non-jdk compiler for JSP compilation when using glassfish uncomment next line
# -Dorg.apache.jasper.compiler.disablejsr199=true

# --------------------------------------- 
# Module: jstl
--module=jstl
# JSTL Configuration
# The glassfish jsp-impl includes JSTL by default and this module
# is not required to activate it.
# The apache jsp-impl does not include JSTL by default and this module
# is required to put JSTL on the container classpath

# --------------------------------------- 
# Module: https or http, depending upon the setting of CONFIG_EXT_SSL_HOSTNAME

%(CONFIG_EXT_SSL_HOSTNAME:||
--module=http
jetty.port=8443
|
--module=https
jetty.port=8443
)

## HTTP idle timeout in milliseconds
http.timeout=30000

## HTTP Socket.soLingerTime in seconds. (-1 to disable)
# http.soLingerTime=-1

## Parameters to control the number and priority of acceptors and selectors
# http.selectors=1
# http.acceptors=1
# http.selectorPriorityDelta=0
# http.acceptorPriorityDelta=0

# Setup keystore
jetty.keystore=../../var/certs/jetty.keystore
jetty.truststore=../../var/certs/jetty.keystore
jetty.keystore.password=%(`jpassword jetty %(KEYSTORE_PASSWORD) 2>&1 | sed -n '/^OBF/p'`)
jetty.keymanager.password=%(`jpassword jetty %(EXPORT_PASSWORD) 2>&1 | sed -n '/^OBF/p'`)
jetty.truststore.password=%(`jpassword jetty %(KEYSTORE_PASSWORD) 2>&1 | sed -n '/^OBF/p'`)
